@@ -13,9 +13,12 @@ class SQLiteConnector(DBBaseConnector):
         self.cnx = sqlite3.connect(self.source)
         self.cur = self.cnx.cursor
 
-    def get_pandas_df(self, query):
+    def get_pandas_df(self, query, verbose_output=False):
         """Get Pandas dataframe"""
 
+        if verbose_output:
+            self.log(f'Query: {query}')
+
         return pd.read_sql_query(query, self.cnx)
     
     def persist_pandas_df(self, table, schema=None, df=None, chunksize=10000, if_exists='replace'):
